pub enum SourceError {
NotImplemented,
Network(String),
Parse(String),
InvalidRequest(String),
RateLimit,
NotFound(String),
Api(String),
Io(Error),
Other(String),
}Expand description
Errors that can occur when interacting with a source
Variants
NotImplemented
The requested operation is not implemented for this source
Network(String)
Network or HTTP error
Parse(String)
Parsing error (XML, JSON, HTML, etc.)
InvalidRequest(String)
Invalid request parameters
RateLimit
Rate limit exceeded
NotFound(String)
Paper not found
Api(String)
API error from the source
Io(Error)
IO error (file system)
Other(String)
Other error