pub fn validate_doi(doi: &str) -> Result<String, ValidationError>Expand description
Validate and sanitize a DOI
DOIs have the format “10.xxxx/xxxxxx” where xxxx is a registrant code and xxxxxx is an item ID.
pub fn validate_doi(doi: &str) -> Result<String, ValidationError>Validate and sanitize a DOI
DOIs have the format “10.xxxx/xxxxxx” where xxxx is a registrant code and xxxxxx is an item ID.