pub struct ConcurrentPaperStream { /* private fields */ }Expand description
A channel-based concurrent stream for parallel source searches.
This allows searching multiple sources concurrently and yielding results as they arrive.
Implementations
Sourceimpl ConcurrentPaperStream
impl ConcurrentPaperStream
Sourcepub async fn from_sources<S: Source + Clone + 'static>(
sources: Vec<S>,
query: &SearchQuery,
max_concurrent: usize,
) -> Self
pub async fn from_sources<S: Source + Clone + 'static>( sources: Vec<S>, query: &SearchQuery, max_concurrent: usize, ) -> Self
Create a new concurrent stream from a list of sources
Searches all sources concurrently and yields papers in the order they complete.