pub struct McpServer { /* private fields */ }Expand description
The MCP server for Research Master
This server provides tools for searching and downloading academic papers from multiple research sources over various transports.
Implementations
Sourceimpl McpServer
impl McpServer
Sourcepub fn new(sources: Arc<SourceRegistry>) -> Result<Self, Error>
pub fn new(sources: Arc<SourceRegistry>) -> Result<Self, Error>
Create a new MCP server with the given source registry
Sourcepub async fn run(&self) -> Result<(), Error>
pub async fn run(&self) -> Result<(), Error>
Run the server in stdio mode (for Claude Desktop and other MCP clients)
Sourcepub async fn run_http(
&self,
addr: &str,
) -> Result<(SocketAddr, JoinHandle<()>), Error>
pub async fn run_http( &self, addr: &str, ) -> Result<(SocketAddr, JoinHandle<()>), Error>
Run the server in HTTP/SSE mode
This starts an HTTP server that uses Server-Sent Events (SSE) for real-time communication with MCP clients.
Sourcepub async fn run_http_with_config(
&self,
addr: &str,
config: StreamableHttpServerConfig,
) -> Result<(SocketAddr, JoinHandle<()>), Error>
pub async fn run_http_with_config( &self, addr: &str, config: StreamableHttpServerConfig, ) -> Result<(SocketAddr, JoinHandle<()>), Error>
Run the server in HTTP/SSE mode with custom configuration