pub struct SourceRegistry { /* private fields */ }Expand description
Registry for all available research sources
The SourceRegistry manages all available source plugins and provides methods to query and use them.
Implementations
Sourceimpl SourceRegistry
impl SourceRegistry
Sourcepub fn try_new() -> Result<Self, SourceError>
pub fn try_new() -> Result<Self, SourceError>
Try to create a new registry with all available sources
This will:
- Filter sources based on config file or environment variables
- Skip sources that fail to initialize (e.g., missing API keys)
- Return an error only if no sources could be initialized
Sourcepub fn get_required(&self, id: &str) -> Result<&Arc<dyn Source>, SourceError>
pub fn get_required(&self, id: &str) -> Result<&Arc<dyn Source>, SourceError>
Get a source by ID, returning an error if not found
Sourcepub fn with_capability(
&self,
capability: SourceCapabilities,
) -> Vec<&Arc<dyn Source>>
pub fn with_capability( &self, capability: SourceCapabilities, ) -> Vec<&Arc<dyn Source>>
Get sources that support a specific capability
Sourcepub fn searchable(&self) -> Vec<&Arc<dyn Source>>
pub fn searchable(&self) -> Vec<&Arc<dyn Source>>
Get sources that support search
Sourcepub fn downloadable(&self) -> Vec<&Arc<dyn Source>>
pub fn downloadable(&self) -> Vec<&Arc<dyn Source>>
Get sources that support download
Sourcepub fn with_citations(&self) -> Vec<&Arc<dyn Source>>
pub fn with_citations(&self) -> Vec<&Arc<dyn Source>>
Get sources that support citations